@@ -575,6 +575,8 @@ def __importModules__():
                         worker("import-module-{m}".format(m=module_name), 'ht.__importModule__', args=(modu, submod, module_name), loop=False, log=False) # Threaded
                     else:
                         __importModule__(modules=modu, category=submod, moduleName=module_name)
+                        if 'urlshortener' in module_name:
+                            print(__modules_loaded__)
                 except Exception as e:
                     Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
                     pass
